ui

package
v0.5.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: MPL-2.0 Imports: 7 Imported by: 0

Documentation

Overview

templ: version: v0.3.1001

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConnectionSteps

func ConnectionSteps(current ConnectionStep) templ.Component

Types

type ConnectionStep

type ConnectionStep int
const (
	ConnectStep ConnectionStep = iota
	SelectRepoStep
)

steps for connecting a workspace/module to repo

type Handlers

type Handlers struct {
	Handlers []internal.Handlers
}

Handlers is the collection of UI handlers

func (*Handlers) AddHandlers

func (h *Handlers) AddHandlers(r *mux.Router)
type Link struct {
	Name string
	Link string
}

type ReposTable

type ReposTable struct {
	Actions func(repo vcs.Repo) templ.Component
}

func (ReposTable) Header

func (t ReposTable) Header() templ.Component

func (ReposTable) Row

func (t ReposTable) Row(repo vcs.Repo) templ.Component

Directories

Path Synopsis
templ: version: v0.3.1001
templ: version: v0.3.1001
Package paths provides rails-style path helpers for use with the web app.
Package paths provides rails-style path helpers for use with the web app.
Package session handles user sessions.
Package session handles user sessions.
Package static contains static assets and code relating to serving of static assets.
Package static contains static assets and code relating to serving of static assets.

Jump to