Documentation
¶
Overview ¶
templ: version: v0.3.1001
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConnectionSteps ¶
func ConnectionSteps(current ConnectionStep) templ.Component
Types ¶
type ConnectionStep ¶
type ConnectionStep int
const ( ConnectStep ConnectionStep = iota SelectRepoStep )
steps for connecting a workspace/module to repo
Directories
¶
| Path | Synopsis |
|---|---|
|
templ: version: v0.3.1001
|
templ: version: v0.3.1001 |
|
Package paths provides rails-style path helpers for use with the web app.
|
Package paths provides rails-style path helpers for use with the web app. |
|
Package session handles user sessions.
|
Package session handles user sessions. |
|
Package static contains static assets and code relating to serving of static assets.
|
Package static contains static assets and code relating to serving of static assets. |
Click to show internal directories.
Click to hide internal directories.